@@ -1,10 +1,9 @@
 from __future__ import annotations
 
-from inspect import isfunction
 from typing import TYPE_CHECKING
 
+from dtoolkit.transformer._util import snake_to_camel
 from dtoolkit.transformer.base import MethodTF
-from dtoolkit.util.generic import snake_to_camel
 
 if TYPE_CHECKING:
     from typing import Callable
@@ -12,7 +11,7 @@ if TYPE_CHECKING:
 
 def methodtf_factory(
     transform_method: Callable,
-    inverse_transform_method: Callable | None = None,
+    inverse_transform_method: Callable = None,
 ) -> MethodTF:
     """
     Quickly generate transformer from methods.
@@ -21,6 +20,7 @@ def methodtf_factory(
     ----------
     transform_method : Callable
         The back algorithm of the :func:`~MethodTF.transform`.
+
     inverse_transform_method : Callable or None
         The back algorithm of the :func:`~MethodTF.inverse_transform`.
 
@@ -72,11 +72,11 @@ def methodtf_factory(
         [0 1 2]
     """
 
-    if not isfunction(transform_method):
+    if not callable(transform_method):
         raise TypeError("'transform_method' must be a function.")
 
     if (inverse_transform_method is not None) and (
-        not isfunction(inverse_transform_method)
+        not callable(inverse_transform_method)
     ):
         raise TypeError("'inverse_transform_method' must be a function.")
 
